@@ -10,36 +10,36 @@
 
 use Curses;
 
-  initscr();
-  start_color();
+initscr();
+start_color();
 
-  cbreak();
-  raw();
-  noecho();
-  nonl();
+cbreak();
+raw();
+noecho();
+nonl();
 
-  # Both of these achieve nonblocking input.
-  nodelay(1);
-  timeout(0);
+# Both of these achieve nonblocking input.
+nodelay(1);
+timeout(0);
 
-  keypad(1);
-  intrflush(0);
-  meta(1);
-  typeahead(-1);
+keypad(1);
+intrflush(0);
+meta(1);
+typeahead(-1);
 
-  my $old_mouse_events = 0;
-  mousemask(REPORT_MOUSE_POSITION, $old_mouse_events); # ALL_MOUSE_EVENTS
+my $old_mouse_events = 0;
+mousemask( REPORT_MOUSE_POSITION, $old_mouse_events ); # ALL_MOUSE_EVENTS
 
-  clear();
-  refresh();
+clear();
+refresh();
 
 
 print STDERR " start\n";
 
-while (my $keystroke = Curses::getch) {
+while ( my $keystroke = Curses::getch ) {
 	$keystroke eq '-1' and next;
 	print STDERR " key : $keystroke\n";
-	$keystroke eq 'q' and last
+	$keystroke eq 'q' and last;
 }
 
 endwin;
\ No newline at end of file
