@@ -17,40 +17,42 @@ use HTML::Parser;
 # underline
 
 my @stack;
+
 # Create parser object
-$p = HTML::Parser->new( api_version => 3,
-						start_h => [ \&start, "tagname, dtext, attr, text"],
-						end_h   => [\&end, "tagname,dtext, attr"],
-						default_h   => [\&default, "dtext"],
-					  );
+$p = HTML::Parser->new(
+	api_version => 3,
+	start_h     => [ \&start, "tagname, dtext, attr, text" ],
+	end_h       => [ \&end, "tagname,dtext, attr" ],
+	default_h   => [ \&default, "dtext" ],
+);
 
 # Parse document text chunk by chunk
 $p->parse('This is <h1 a=b>a</h1><span bold,italic> good <span underline="true">example</span>, another </span>chunk');
-$p->eof;                 # signal end of document
+$p->eof; # signal end of document
 print "\n";
 
 sub start {
-	my ($tagname, $dtext, $attr, $text) = @_;
-	if      ($tagname eq 'span') {
+	my ( $tagname, $dtext, $attr, $text ) = @_;
+	if ( $tagname eq 'span' ) {
 		print "[SPAN]";
 		print Dumper($attr); use Data::Dumper;
-	} elsif ($tagname eq 'b') {
+	} elsif ( $tagname eq 'b' ) {
 		print "[B]";
-	} elsif ($tagname eq 'u') {
-		print "[U]";		
+	} elsif ( $tagname eq 'u' ) {
+		print "[U]";
 	} else {
 		print "$text";
 	}
 }
 
 sub end {
-	my ($tagname, $dtext, $attr) = @_;
-	if      ($tagname eq 'span') {
-		print "[span]";		
-	} elsif ($tagname eq 'b') {
+	my ( $tagname, $dtext, $attr ) = @_;
+	if ( $tagname eq 'span' ) {
+		print "[span]";
+	} elsif ( $tagname eq 'b' ) {
 		print "[b]";
-	} elsif ($tagname eq 'u') {
-		print "[u]";		
+	} elsif ( $tagname eq 'u' ) {
+		print "[u]";
 	} else {
 		my ($dtext) = @_;
 		print "$text";
