@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Event::Key;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: event that is related to keystrokes
@@ -21,62 +22,68 @@ use Params::Validate qw(:all);
 
 
 sub new {
-	my $class = shift;
-	my $self = $class->SUPER::new();
-	my %args = validate( @_,
-						 { type => 
-						   { type => SCALAR,
-							 callbacks => { 'must be one of ' . join(', ', $self->get_types()) =>
-											sub { my %h = map { $_ => 1 } $self->get_types(); $h{ $_[0] }; },
-										  }
-						   },
-						   params => 0,
-						   root_window => { isa => 'Curses::Toolkit' },
-						 },
-					   );
-	$args{params} ||= {};
-	my @args = $args{params};
-	my $definition = $self->get_params_definition($args{type});
-	my %params = validate( @args, $definition ),
-	$self->{type}   = $args{type};
-	$self->{root_window}   = $args{root_window};
-	$self->{params} = \%params;
-	return $self;
+    my $class = shift;
+    my $self  = $class->SUPER::new();
+    my %args  = validate(
+        @_,
+        {   type => {
+                type      => SCALAR,
+                callbacks => {
+                    'must be one of ' . join( ', ', $self->get_types() ) => sub {
+                        my %h = map { $_ => 1 } $self->get_types(); $h{ $_[0] };
+                    },
+                }
+            },
+            params      => 0,
+            root_window => { isa => 'Curses::Toolkit' },
+        },
+    );
+    $args{params} ||= {};
+    my @args       = $args{params};
+    my $definition = $self->get_params_definition( $args{type} );
+    my %params     = validate( @args, $definition ), $self->{type} = $args{type};
+    $self->{root_window} = $args{root_window};
+    $self->{params}      = \%params;
+    return $self;
 }
 
 
-my %types = ( stroke => { key => { type => SCALAR,
-								   callbacks => { 
-												 non_empty => sub { length($_[0]) }
-												}
-								 }
-						},
-			  press => {},
-			  release => {},
-			);
+my %types = (
+    stroke => {
+        key => {
+            type      => SCALAR,
+            callbacks => {
+                non_empty => sub { length( $_[0] ) }
+            }
+        }
+    },
+    press   => {},
+    release => {},
+);
+
 sub get_types {
-	my ($self) = @_;
-	return keys %types;
+    my ($self) = @_;
+    return keys %types;
 }
 
 
 sub get_params_definition {
-	my ($self, $type) = @_;
-	return $types{$type};
+    my ( $self, $type ) = @_;
+    return $types{$type};
 }
 
 
 sub get_matching_widget {
-	my ($self) = @_;
-	my $root = $self->{root_window};
-	my $widget;
-	defined $widget or
-	  $widget = $root->get_focused_widget();
-	defined $widget or
-	  $widget = $root->get_focused_window();
-	defined $widget or
-	  $widget = $root;
-	return $widget;
+    my ($self) = @_;
+    my $root = $self->{root_window};
+    my $widget;
+    defined $widget
+        or $widget = $root->get_focused_widget();
+    defined $widget
+        or $widget = $root->get_focused_window();
+    defined $widget
+        or $widget = $root;
+    return $widget;
 }
 
 1;
@@ -91,7 +98,7 @@ Curses::Toolkit::Event::Key - event that is related to keystrokes
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
