@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Object::Flags;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: simple collection of flags
@@ -19,12 +20,13 @@ use parent qw(Curses::Toolkit::Object);
 
 
 sub new {
-	my $class = shift;
-	my $self = bless { focused  => 0,
-				 selected => 0,
-				 clicked  => 0,
-			   }, $class;
-	return $self;
+    my $class = shift;
+    my $self  = bless {
+        focused  => 0,
+        selected => 0,
+        clicked  => 0,
+    }, $class;
+    return $self;
 }
 
 1;
@@ -39,7 +41,7 @@ Curses::Toolkit::Object::Flags - simple collection of flags
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
