@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Role::Focusable;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: This role implements the fact that a widget can have focus
@@ -22,54 +23,52 @@ use Params::Validate qw(:all);
 
 sub new {
     my ($class) = shift;
+
     # TODO : use Exception;
     # $class eq __PACKAGE__ and;
-	die "role class, has no constructor";
+    die "role class, has no constructor";
 }
 
 
 sub is_focusable {
     my ($self) = @_;
-	return($self->is_sensitive() ? 1 : 0);
+    return ( $self->is_sensitive() ? 1 : 0 );
 }
 
 
 sub set_focus {
-	my $self = shift;
-	my ($focus) = validate_pos( @_, { type => BOOLEAN } );
+    my $self = shift;
+    my ($focus) = validate_pos( @_, { type => BOOLEAN } );
 
-	$self->is_focusable()
-	  or return $self;
-	
-	if ($self->can('get_window')) {
-		my $window = $self->get_window();
-		if (defined $window) {
-			if ($focus) {
-				use Curses::Toolkit::Event::Focus::In;
-				# restrict the event to the widget
-				my $event_focus_in = Curses::Toolkit::Event::Focus::In
-				                     ->new
-									 ->enable_restriction;
-				$self->fire_event($event_focus_in, $self);
-				$window->set_focused_widget($self);
-			} else {
-				use Curses::Toolkit::Event::Focus::Out;
-				my $event_focus_out = Curses::Toolkit::Event::Focus::Out
-				                      ->new
-									  ->enable_restriction;
-				$self->fire_event($event_focus_out, $self);
-			}
-		}
-	}
-	$self->set_property(basic => 'focused', $focus ? 1 : 0);
-	$self->needs_redraw();
-	return $self;
+    $self->is_focusable()
+        or return $self;
+
+    if ( $self->can('get_window') ) {
+        my $window = $self->get_window();
+        if ( defined $window ) {
+            if ($focus) {
+                use Curses::Toolkit::Event::Focus::In;
+
+                # restrict the event to the widget
+                my $event_focus_in = Curses::Toolkit::Event::Focus::In->new->enable_restriction;
+                $self->fire_event( $event_focus_in, $self );
+                $window->set_focused_widget($self);
+            } else {
+                use Curses::Toolkit::Event::Focus::Out;
+                my $event_focus_out = Curses::Toolkit::Event::Focus::Out->new->enable_restriction;
+                $self->fire_event( $event_focus_out, $self );
+            }
+        }
+    }
+    $self->set_property( basic => 'focused', $focus ? 1 : 0 );
+    $self->needs_redraw();
+    return $self;
 }
 
 
 sub is_focused {
-	my ($self) = @_;
-	return $self->get_property(basic => 'focused');
+    my ($self) = @_;
+    return $self->get_property( basic => 'focused' );
 }
 
 1;
@@ -86,7 +85,7 @@ Curses::Toolkit::Role::Focusable - This role implements the fact that a widget c
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
