@@ -10,7 +10,7 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Signal::Content::Changed;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
 
 
 
@@ -20,28 +20,29 @@ use Params::Validate qw(:all);
 
 
 sub generate_listener {
-	my $class = shift;
-	my %args = validate( @_,
-						 { widget => { isa => 'Curses::Toolkit::Widget' },
-						   code_ref => { type => CODEREF },
-						   arguments => { type => ARRAYREF },
-						 },
-					   );
-	my $widget = $args{widget};
-	my $code_ref = $args{code_ref};
-	my @arguments = @{$args{arguments}};
+    my $class = shift;
+    my %args  = validate(
+        @_,
+        {   widget    => { isa  => 'Curses::Toolkit::Widget' },
+            code_ref  => { type => CODEREF },
+            arguments => { type => ARRAYREF },
+        },
+    );
+    my $widget    = $args{widget};
+    my $code_ref  = $args{code_ref};
+    my @arguments = @{ $args{arguments} };
 
-	return Curses::Toolkit::EventListener->new(
-		accepted_events => {
-			'Curses::Toolkit::Event::Content::Changed' => sub { 
-				my ($event) = @_;
-				return 1;
-			},
-		},
-		code => sub {
-			$code_ref->(@_, @arguments);
-		},
-	);
+    return Curses::Toolkit::EventListener->new(
+        accepted_events => {
+            'Curses::Toolkit::Event::Content::Changed' => sub {
+                my ($event) = @_;
+                return 1;
+            },
+        },
+        code => sub {
+            $code_ref->( @_, @arguments );
+        },
+    );
 }
 
 1;
@@ -52,7 +53,7 @@ __END__
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 NAME
 
