@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: base class for widgets
@@ -20,123 +21,127 @@ use Params::Validate qw(:all);
 
 sub new {
     my ($class) = shift;
+
     # TODO : use Exception;
     $class eq __PACKAGE__ and die "abstract class";
-	use Curses::Toolkit::Object::Flags;
-	my $self = bless { flags => Curses::Toolkit::Object::Flags->new(),
-					   parent => undef,
-					   name => 'unknown',
-					   relatives_coordinates => Curses::Toolkit::Object::Coordinates
-					   ->new_zero(),
-					   properties => {},
-					   event_listeners => {},
-					   next_index => 0,
-					 }, $class;
-	$self->set_sensitive(1);
-	$self->set_visible(1);
-	return $self;
+    use Curses::Toolkit::Object::Flags;
+    my $self = bless {
+        flags                 => Curses::Toolkit::Object::Flags->new(),
+        parent                => undef,
+        name                  => 'unknown',
+        relatives_coordinates => Curses::Toolkit::Object::Coordinates
+            ->new_zero(),
+        properties      => {},
+        event_listeners => {},
+        next_index      => 0,
+    }, $class;
+    $self->set_sensitive(1);
+    $self->set_visible(1);
+    return $self;
 }
 
 
 sub set_name {
-	my ($self, $name) = @_;
-	$self->{name} = $name;
-	return $self;
+    my ( $self, $name ) = @_;
+    $self->{name} = $name;
+    return $self;
 }
 
 
 sub get_name {
-	my ($self) = @_;
-	return $self->{name};
+    my ($self) = @_;
+    return $self->{name};
 }
 
 
 sub set_sensitive {
-	my $self = shift;
-	my ($sensitiveness) = validate_pos( @_, { type => BOOLEAN } );
-	$self->set_property(basic => 'sensitive', $sensitiveness ? 1 : 0);
-	return $self;
+    my $self = shift;
+    my ($sensitiveness) = validate_pos( @_, { type => BOOLEAN } );
+    $self->set_property( basic => 'sensitive', $sensitiveness ? 1 : 0 );
+    return $self;
 }
 
 
 sub is_sensitive {
-	my ($self) = @_;
-	return $self->get_property(basic => 'sensitive');
+    my ($self) = @_;
+    return $self->get_property( basic => 'sensitive' );
 }
 
 
 sub set_visible {
-	my $self = shift;
-	my ($visibility) = validate_pos( @_, { type => BOOLEAN } );
-	$self->set_property(basic => 'visible', $visibility ? 1 : 0);
-	return $self;
+    my $self = shift;
+    my ($visibility) = validate_pos( @_, { type => BOOLEAN } );
+    $self->set_property( basic => 'visible', $visibility ? 1 : 0 );
+    return $self;
 }
 
 
 sub is_visible {
-	my ($self) = @_;
-	return $self->get_property(basic => 'visible');
+    my ($self) = @_;
+    return $self->get_property( basic => 'visible' );
 }
 
 
 sub set_property {
-	my $self = shift;
-	my ($group_name, $property_name, $value) = validate_pos( @_, 1, 1, 0 );
+    my $self = shift;
+    my ( $group_name, $property_name, $value ) = validate_pos( @_, 1, 1, 0 );
 
-	if (ref $property_name eq 'HASH') {
-		my $group_value = $property_name;
-		$self->{property}{$group_name} = $group_value;
-	} else {
-		$self->{property}{$group_name}{$property_name} = $value;
-	}
-	return $self;
+    if ( ref $property_name eq 'HASH' ) {
+        my $group_value = $property_name;
+        $self->{property}{$group_name} = $group_value;
+    } else {
+        $self->{property}{$group_name}{$property_name} = $value;
+    }
+    return $self;
 }
 
 
 sub get_property {
-	my ($self, $group_name, $property_name) = validate_pos( @_, { isa => 'Curses::Toolkit::Widget' }, { optional => 0 }, { optional => 1} );
-	my $group = $self->{property}{$group_name};
-	defined $group or $group = {};
-	if (defined $property_name) {
-		return $group->{$property_name};
-	}
-	return( { %$group } );
+    my ( $self, $group_name, $property_name ) =
+        validate_pos( @_, { isa => 'Curses::Toolkit::Widget' }, { optional => 0 }, { optional => 1 } );
+    my $group = $self->{property}{$group_name};
+    defined $group or $group = {};
+    if ( defined $property_name ) {
+        return $group->{$property_name};
+    }
+    return ( {%$group} );
 }
 
 
 sub set_theme_property {
-	my $self = shift;
-	$self->get_theme->set_property(ref $self, @_);
-	return $self;
+    my $self = shift;
+    $self->get_theme->set_property( ref $self, @_ );
+    return $self;
 }
 
 
 sub get_theme_property {
-	my $self = shift;
-	$self->get_theme->get_property(ref $self, @_);
+    my $self = shift;
+    $self->get_theme->get_property( ref $self, @_ );
 }
 
 # Default theme properties : no theme properties
 sub _get_theme_properties_definition {
-	my ($self) = @_;
-	return {};
+    my ($self) = @_;
+    return {};
 }
 
 
 sub add_event_listener {
-	my $self = shift;
-	my ($listener) = validate_pos( @_, { isa => 'Curses::Toolkit::EventListener' } );
-	my $index = $self->_get_next_index();
-	$self->{event_listeners}->{$index} = $listener;
-#	push @{$self->{event_listeners}}, $listener;
-	$listener->_set_widget($self, $index);
-	return $self;
+    my $self = shift;
+    my ($listener) = validate_pos( @_, { isa => 'Curses::Toolkit::EventListener' } );
+    my $index = $self->_get_next_index();
+    $self->{event_listeners}->{$index} = $listener;
+
+    #	push @{$self->{event_listeners}}, $listener;
+    $listener->_set_widget( $self, $index );
+    return $self;
 }
 
 
 sub get_event_listeners {
-	my ($self) = @_;
-	return values %{$self->{event_listeners}};
+    my ($self) = @_;
+    return values %{ $self->{event_listeners} };
 }
 
 # given its index, unlink the event listener from the widget
@@ -144,18 +149,18 @@ sub get_event_listeners {
 # output : the widget
 
 sub _remove_event_listener {
-	my ($self, $index) = @_;
-	delete $self->{event_listeners}{$index};
-	return $self;
+    my ( $self, $index ) = @_;
+    delete $self->{event_listeners}{$index};
+    return $self;
 }
 
 
 sub fire_event {
-	my $self = shift;
-	my $root_window = $self->get_root_window()
-	  or return $self;
-	$root_window->fire_event(@_);
-	return $self;
+    my $self        = shift;
+    my $root_window = $self->get_root_window()
+        or return $self;
+    $root_window->fire_event(@_);
+    return $self;
 }
 
 
@@ -163,8 +168,8 @@ sub draw { return; }
 
 
 sub render {
-	my ($self) = @_;
-	$self->draw();
+    my ($self) = @_;
+    $self->draw();
     return;
 }
 
@@ -174,92 +179,94 @@ sub render {
 #  output : the current widget
 
 sub _set_parent {
-	my $self = shift;
-	my ($widget) = validate_pos( @_, { isa => 'Curses::Toolkit::Widget::Container' } );
-	$self->{parent} = $widget;
-	return $self;
+    my $self = shift;
+    my ($widget) = validate_pos( @_, { isa => 'Curses::Toolkit::Widget::Container' } );
+    $self->{parent} = $widget;
+    return $self;
 }
 
 
 sub get_parent {
-	my ($self) = @_;
-	return $self->{parent};
+    my ($self) = @_;
+    return $self->{parent};
 }
 
 
 sub set_theme_name {
-	my $self = shift;
-    my ($theme_name, $recurse) = validate_pos( @_, { type => SCALAR },
-											       { type => BOOLEAN, optional => 1 },
-											 );
-	$self->{theme_name} = $theme_name;
-	$self->{theme} = undef;
-	if ($recurse) {
-		if ($self->isa('Curses::Toolkit::Widget::Container')) {		
-			my @children = $self->get_children();
-			# to avoid rebuilding coordinates at every stage of the recursion,
-			# rebuild them only at leaves
-			@children
-			  or $self->rebuild_all_coordinates();
-			foreach my $child (@children) {
-				$child->set_theme_name($theme_name, $recurse);
-			}
-		}
-	} else {
-		$self->rebuild_all_coordinates();
-	}
-	return $self;
+    my $self = shift;
+    my ( $theme_name, $recurse ) = validate_pos(
+        @_, { type => SCALAR },
+        { type => BOOLEAN, optional => 1 },
+    );
+    $self->{theme_name} = $theme_name;
+    $self->{theme}      = undef;
+    if ($recurse) {
+        if ( $self->isa('Curses::Toolkit::Widget::Container') ) {
+            my @children = $self->get_children();
+
+            # to avoid rebuilding coordinates at every stage of the recursion,
+            # rebuild them only at leaves
+            @children
+                or $self->rebuild_all_coordinates();
+            foreach my $child (@children) {
+                $child->set_theme_name( $theme_name, $recurse );
+            }
+        }
+    } else {
+        $self->rebuild_all_coordinates();
+    }
+    return $self;
 }
 
 
 sub get_theme_name {
-	my ($self) = @_;
-	if ( ! defined $self->{theme_name} ) {
-		my $parent = $self->isa('Curses::Toolkit::Widget::Window') ?
-		  $self->get_root_window() : $self->get_parent();
-		defined $parent and
-		  return $parent->get_theme_name();
-		# If the widget is floating in the void (not on a root window), return
-		# void
-		return;
-	}
-	return $self->{theme_name};
+    my ($self) = @_;
+    if ( !defined $self->{theme_name} ) {
+        my $parent = $self->isa('Curses::Toolkit::Widget::Window') ? $self->get_root_window() : $self->get_parent();
+        defined $parent
+            and return $parent->get_theme_name();
+
+        # If the widget is floating in the void (not on a root window), return
+        # void
+        return;
+    }
+    return $self->{theme_name};
 }
 
 
 sub get_theme {
-	my ($self) = @_;
-	if ( ! defined $self->{theme} ) {
-		my $theme_name = $self->get_theme_name();
-		if (defined $theme_name) {
-			$self->{theme} = $self->get_theme_name()->new($self);
-		} else {
-			my $theme_name = Curses::Toolkit->get_default_theme_name();
-			return $theme_name->new($self);
-		}
-	}
-	return $self->{theme};
+    my ($self) = @_;
+    if ( !defined $self->{theme} ) {
+        my $theme_name = $self->get_theme_name();
+        if ( defined $theme_name ) {
+            $self->{theme} = $self->get_theme_name()->new($self);
+        } else {
+            my $theme_name = Curses::Toolkit->get_default_theme_name();
+            return $theme_name->new($self);
+        }
+    }
+    return $self->{theme};
 }
 
 
 sub get_window {
-	my ($self) = @_;
-	my $widget = $self;
-	while ( ! $widget->isa('Curses::Toolkit::Widget::Window') ) {
-		$widget = $widget->get_parent();
-		defined $widget or return;
-	}
-	return $widget;
+    my ($self) = @_;
+    my $widget = $self;
+    while ( !$widget->isa('Curses::Toolkit::Widget::Window') ) {
+        $widget = $widget->get_parent();
+        defined $widget or return;
+    }
+    return $widget;
 }
 
 
 sub get_root_window {
-	my ($self) = @_;
-	my $window = $self->get_window()
-	  or return;
-	my $root_window = $window->get_root_window()
-	  or return;
-	return $root_window;
+    my ($self) = @_;
+    my $window = $self->get_window()
+        or return;
+    my $root_window = $window->get_root_window()
+        or return;
+    return $root_window;
 }
 
 # =head2 set_border_width
@@ -279,78 +286,79 @@ sub get_root_window {
 
 
 sub get_coordinates {
-	my ($self) = @_;
-	defined $self->{coordinates} and
-	  return $self->{coordinates};
-	my $parent = $self->get_parent();
-	if (defined $parent) {
-		my $pc = $parent->get_coordinates();
-		my $rc = $self->get_relatives_coordinates();
-		use Curses::Toolkit::Object::Coordinates;
-		my $c = Curses::Toolkit::Object::Coordinates->new(
-			x1 => $pc->x1() + $rc->x1(), y1 => $pc->y1() + $rc->y1(),
-			x2 => $pc->x1() + $rc->x2(), y2 => $pc->y1() + $rc->y2(),
-		);
-		return $c;
-	}
-	die "widget of name '" . $self->get_name() . "' (type '" . ref($self) . "') has no coordinates.";
+    my ($self) = @_;
+    defined $self->{coordinates}
+        and return $self->{coordinates};
+    my $parent = $self->get_parent();
+    if ( defined $parent ) {
+        my $pc = $parent->get_coordinates();
+        my $rc = $self->get_relatives_coordinates();
+        use Curses::Toolkit::Object::Coordinates;
+        my $c = Curses::Toolkit::Object::Coordinates->new(
+            x1 => $pc->x1() + $rc->x1(), y1 => $pc->y1() + $rc->y1(),
+            x2 => $pc->x1() + $rc->x2(), y2 => $pc->y1() + $rc->y2(),
+        );
+        return $c;
+    }
+    die "widget of name '" . $self->get_name() . "' (type '" . ref($self) . "') has no coordinates.";
 }
 
 
 sub get_relatives_coordinates {
-	my ($self) = @_;
-	defined $self->{relatives_coordinates} or
-	  die "widget of name '" . $self->get_name() . "' (type '" . ref($self) . "') has no relatives coordinate\n";
-	return $self->{relatives_coordinates};
+    my ($self) = @_;
+    defined $self->{relatives_coordinates}
+        or die "widget of name '" . $self->get_name() . "' (type '" . ref($self) . "') has no relatives coordinate\n";
+    return $self->{relatives_coordinates};
 }
 
 
 sub get_visible_shape {
-	my ($self) = @_;
-	my $shape = $self->get_coordinates->clone;
-	my $parent = $self->get_parent;
-	defined $parent
-	  and $shape->restrict_to($parent->get_visible_shape);
-	return $shape;
+    my ($self) = @_;
+    my $shape  = $self->get_coordinates->clone;
+    my $parent = $self->get_parent;
+    defined $parent
+        and $shape->restrict_to( $parent->get_visible_shape );
+    return $shape;
 }
 
 
 sub rebuild_all_coordinates {
-	my ($self) = @_;
-	my $widget = $self;
+    my ($self) = @_;
+    my $widget = $self;
 
-	my $window = $widget->get_window();
-	if ( ! defined $window ) {
-		# if the widget is not part of a window, just return : we can't rebuild
-		# the coordinates. We were probably called during the construction of a
-		# complicated window, and widgets were created before being added to
-		# the window
-		return $self;
-	}
-	$window->_rebuild_children_coordinates();
-	$self->needs_redraw();
-	return $self;	
+    my $window = $widget->get_window();
+    if ( !defined $window ) {
+
+        # if the widget is not part of a window, just return : we can't rebuild
+        # the coordinates. We were probably called during the construction of a
+        # complicated window, and widgets were created before being added to
+        # the window
+        return $self;
+    }
+    $window->_rebuild_children_coordinates();
+    $self->needs_redraw();
+    return $self;
 }
 
 
 sub needs_redraw {
-	my ($self) = @_;
-	my $window = $self->get_window();
-	defined $window or return $self;
-	my $root_window = $window->get_root_window();
-	defined $root_window or return $self;
-	$root_window->needs_redraw();
-	return $self;
+    my ($self) = @_;
+    my $window = $self->get_window();
+    defined $window or return $self;
+    my $root_window = $window->get_root_window();
+    defined $root_window or return $self;
+    $root_window->needs_redraw();
+    return $self;
 }
 
 # sets the relatives coordinates, from the origin of the parent widget
 #  input  : any Curses::Toolkit::Object::Coordinates costructor input
 #  output : the widget
 sub _set_relatives_coordinates {
-	my $self = shift;
-	use Curses::Toolkit::Object::Coordinates;
-	$self->{relatives_coordinates} = Curses::Toolkit::Object::Coordinates->new(@_);
-	return $self;
+    my $self = shift;
+    use Curses::Toolkit::Object::Coordinates;
+    $self->{relatives_coordinates} = Curses::Toolkit::Object::Coordinates->new(@_);
+    return $self;
 }
 
 # Sets the Curses object to the widget.
@@ -359,10 +367,10 @@ sub _set_relatives_coordinates {
 #  output : the current widget
 
 sub _set_curses_handler {
-	my $self = shift;
+    my $self = shift;
     my ($curses_handler) = validate_pos( @_, { isa => 'Curses' } );
-	$self->{curses_handler} = $curses_handler;
-	return $self;
+    $self->{curses_handler} = $curses_handler;
+    return $self;
 }
 
 # Returns the Curses object. Typically called when drawing things
@@ -371,73 +379,73 @@ sub _set_curses_handler {
 #  output : a Curses object
 
 sub _get_curses_handler {
-	my ($self) = @_;
-	defined $self->{curses_handler} and
-	  return $self->{curses_handler};
-	my $parent = $self->get_parent();
-	defined $parent and
-	  return $parent->_get_curses_handler();
-	die "couldn't get Curses object from widget (name '" . $self->get_name() . "' type '" . ref($self) ."')";
+    my ($self) = @_;
+    defined $self->{curses_handler}
+        and return $self->{curses_handler};
+    my $parent = $self->get_parent();
+    defined $parent
+        and return $parent->_get_curses_handler();
+    die "couldn't get Curses object from widget (name '" . $self->get_name() . "' type '" . ref($self) . "')";
 }
 
 # set forward / backward iterators for transversal travelling
 
 sub _set_iterator {
-	my ($self, $iterator) = @_;
-	$self->{iterator} = $iterator;
-	return $self;
+    my ( $self, $iterator ) = @_;
+    $self->{iterator} = $iterator;
+    return $self;
 }
 
 sub _get_next_brother {
-	my ($self) = @_;
-	my $iterator = $self->{iterator};
-	defined $iterator or return; # there is no brothers
-	$iterator->next();
-	my $brother_widget = $iterator->value(); # might be undef
-	$iterator->prev();
-	defined $brother_widget and return $brother_widget;
-	return;
+    my ($self) = @_;
+    my $iterator = $self->{iterator};
+    defined $iterator or return; # there is no brothers
+    $iterator->next();
+    my $brother_widget = $iterator->value(); # might be undef
+    $iterator->prev();
+    defined $brother_widget and return $brother_widget;
+    return;
 }
 
 sub _get_prev_brother {
-	my ($self) = @_;
-	my $iterator = $self->{iterator};
-	defined $iterator or return; # there is no brothers
-	$iterator->prev();
-	my $brother_widget = $iterator->value(); # might be undef
-	$iterator->next();
-	defined $brother_widget and return $brother_widget;
-	return;
+    my ($self) = @_;
+    my $iterator = $self->{iterator};
+    defined $iterator or return;             # there is no brothers
+    $iterator->prev();
+    my $brother_widget = $iterator->value(); # might be undef
+    $iterator->next();
+    defined $brother_widget and return $brother_widget;
+    return;
 }
 
 # returns the next available index
 # input  : none
 # output : index number
 sub _get_next_index {
-	my ($self) = @_;
-	return $self->{next_index}++;
+    my ($self) = @_;
+    return $self->{next_index}++;
 }
 
 
 sub set_modal {
-	my ($self) = @_;
-	my $window = $self->get_window();
-	defined $window or return $self;
-	my $root_window = $window->get_root_window();
-	defined $root_window or return $self;
-	$root_window->set_modal_widget($self);
-	return $self;
+    my ($self) = @_;
+    my $window = $self->get_window();
+    defined $window or return $self;
+    my $root_window = $window->get_root_window();
+    defined $root_window or return $self;
+    $root_window->set_modal_widget($self);
+    return $self;
 }
 
 
 sub unset_modal {
-	my ($self) = @_;
-	my $window = $self->get_window();
-	defined $window or return $self;
-	my $root_window = $window->get_root_window();
-	defined $root_window or return $self;
-	$root_window->unset_modal_widget();
-	return $self;
+    my ($self) = @_;
+    my $window = $self->get_window();
+    defined $window or return $self;
+    my $root_window = $window->get_root_window();
+    defined $root_window or return $self;
+    $root_window->unset_modal_widget();
+    return $self;
 }
 
 
@@ -445,68 +453,72 @@ sub unset_modal {
 
 
 sub get_next_focused_widget {
-	my ($self, $dont_avoid_me) = @_;
+    my ( $self, $dont_avoid_me ) = @_;
 
-	my $next_widget;
-	# look down and right
-	$next_widget = $self->_recursive_f1($self, !$dont_avoid_me);
-	defined $next_widget and return $next_widget;
+    my $next_widget;
 
-	# nothing down and right ? look up and right
-	$next_widget = $self->_recursive_f2($self);
-	defined $next_widget and return $next_widget;
+    # look down and right
+    $next_widget = $self->_recursive_f1( $self, !$dont_avoid_me );
+    defined $next_widget and return $next_widget;
 
-	# still nothing ? Start from top and look down
-	my $window = $self->get_window();
-	defined $window or return;
-	return $self->_recursive_f1($window);
+    # nothing down and right ? look up and right
+    $next_widget = $self->_recursive_f2($self);
+    defined $next_widget and return $next_widget;
+
+    # still nothing ? Start from top and look down
+    my $window = $self->get_window();
+    defined $window or return;
+    return $self->_recursive_f1($window);
 }
 
 sub _recursive_f1 {
-	my ($self, $widget, $avoid_me) = @_;
-	# Is the widget focusable ?
-	unless ($avoid_me) {
-		$widget->isa('Curses::Toolkit::Role::Focusable') && $widget->is_focusable()
-		  and return $widget;
-	}
+    my ( $self, $widget, $avoid_me ) = @_;
 
-	# does the widget have any children ?
-	if ($widget->isa('Curses::Toolkit::Widget::Container')) {		
-		my @children = $widget->get_children();
-		if (@children) {
-			my $next_widget = $self->_recursive_f1($children[0]);
-			defined $next_widget and return $next_widget;
-		}
-	}
-	# does the widget have a brother ?
-	my $brother_widget = $widget->_get_next_brother();
-	defined $brother_widget or return;
+    # Is the widget focusable ?
+    unless ($avoid_me) {
+        $widget->isa('Curses::Toolkit::Role::Focusable') && $widget->is_focusable()
+            and return $widget;
+    }
 
-	return $self->_recursive_f1($brother_widget);
+    # does the widget have any children ?
+    if ( $widget->isa('Curses::Toolkit::Widget::Container') ) {
+        my @children = $widget->get_children();
+        if (@children) {
+            my $next_widget = $self->_recursive_f1( $children[0] );
+            defined $next_widget and return $next_widget;
+        }
+    }
+
+    # does the widget have a brother ?
+    my $brother_widget = $widget->_get_next_brother();
+    defined $brother_widget or return;
+
+    return $self->_recursive_f1($brother_widget);
 }
 
 sub _recursive_f2 {
-	my ($self, $widget) = @_;
-	# get parent
-	my $parent_widget = $widget->get_parent();
-	defined $parent_widget or return;
+    my ( $self, $widget ) = @_;
 
-	# is the parent focusable ?
-	$parent_widget->isa('Curses::Toolkit::Role::Focusable') && $parent_widget->is_focusable()
-	  and return $parent_widget;
+    # get parent
+    my $parent_widget = $widget->get_parent();
+    defined $parent_widget or return;
 
-	# if not, apply f1 on its potential brother
-	my $brother_widget = $parent_widget->_get_next_brother();
-	if (defined $brother_widget) {
-		my $next_widget = $self->_recursive_f1($brother_widget);
-		defined $next_widget and return $next_widget;
-	}
+    # is the parent focusable ?
+    $parent_widget->isa('Curses::Toolkit::Role::Focusable') && $parent_widget->is_focusable()
+        and return $parent_widget;
 
-	# still nothing ? call f2
-	my $next_widget = $self->_recursive_f2($parent_widget);
-	defined $next_widget and return $next_widget;
+    # if not, apply f1 on its potential brother
+    my $brother_widget = $parent_widget->_get_next_brother();
+    if ( defined $brother_widget ) {
+        my $next_widget = $self->_recursive_f1($brother_widget);
+        defined $next_widget and return $next_widget;
+    }
 
-	return;
+    # still nothing ? call f2
+    my $next_widget = $self->_recursive_f2($parent_widget);
+    defined $next_widget and return $next_widget;
+
+    return;
 }
 
 # =head2 get_previous_focused_widget
@@ -542,46 +554,54 @@ sub _recursive_f2 {
 
 # default widget signals
 sub possible_signals {
-	my ($self) = @_;
-	$self->isa('Curses::Toolkit::Role::Focusable')
-	  and return ( focus_changed => 'Curses::Toolkit::Signal::Focused',
-				   focused_in => 'Curses::Toolkit::Signal::Focused::In',
-				   focused_out => 'Curses::Toolkit::Signal::Focused::Out',
-				 );
-	return ();
+    my ($self) = @_;
+    $self->isa('Curses::Toolkit::Role::Focusable')
+        and return (
+        focus_changed => 'Curses::Toolkit::Signal::Focused',
+        focused_in    => 'Curses::Toolkit::Signal::Focused::In',
+        focused_out   => 'Curses::Toolkit::Signal::Focused::Out',
+        );
+    return ();
 }
 
 
 sub signal_connect {
-	my $self = shift;
-	my ($signal_name, $code_ref, @arguments) = validate_pos( @_, { type => SCALAR },
-															     { type => CODEREF },
-															     (0) x (@_ - 2),
-														   );
-	$self->_bind_signal($signal_name, $code_ref, @arguments);
-	return $self;
+    my $self = shift;
+    my ( $signal_name, $code_ref, @arguments ) = validate_pos(
+        @_, { type => SCALAR },
+        { type => CODEREF },
+        (0) x ( @_ - 2 ),
+    );
+    $self->_bind_signal( $signal_name, $code_ref, @arguments );
+    return $self;
 }
 
 sub _bind_signal {
-	my $self = shift;
-	my ($signal_name, $code_ref, @arguments) = validate_pos( @_, { type => SCALAR },
-															     { type => CODEREF },
-															     (0) x (@_ - 2),
-														   );
-	my %signals = $self->possible_signals();
-	my $signal_class = $signals{$signal_name};
-	defined $signal_class
-	  or die "signal '$signal_name' doesn't exists for widget of type " . ref($self) . ". Possible signals are : " . join(', ', keys %signals);
+    my $self = shift;
+    my ( $signal_name, $code_ref, @arguments ) = validate_pos(
+        @_, { type => SCALAR },
+        { type => CODEREF },
+        (0) x ( @_ - 2 ),
+    );
+    my %signals      = $self->possible_signals();
+    my $signal_class = $signals{$signal_name};
+    defined $signal_class
+        or die "signal '$signal_name' doesn't exists for widget of type "
+        . ref($self)
+        . ". Possible signals are : "
+        . join( ', ', keys %signals );
 
-	require UNIVERSAL::require;
-	$signal_class->require
-	  or die $@;
-	$self->add_event_listener($signal_class->generate_listener( widget => $self,
-																code_ref => $code_ref,
-																arguments => [ @arguments ],
-															  )
-							 );
-	return $self;
+    require UNIVERSAL::require;
+    $signal_class->require
+        or die $@;
+    $self->add_event_listener(
+        $signal_class->generate_listener(
+            widget    => $self,
+            code_ref  => $code_ref,
+            arguments => [@arguments],
+        )
+    );
+    return $self;
 }
 
 1;
@@ -596,7 +616,7 @@ Curses::Toolkit::Widget - base class for widgets
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
