@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::Bin;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: a bin widget
@@ -23,45 +24,48 @@ use Params::Validate qw(:all);
 
 
 sub add_widget {
-	my $self = shift;
-	my ($child_widget) = validate_pos( @_, { isa => 'Curses::Toolkit::Widget' } );
-	scalar $self->get_children() and
-	  die 'there is already a child widget';
-	$self->_add_child($child_widget);
-	$child_widget->_set_parent($self);
-	# because it's a Bin container, needs to take care of rebuilding coordinates
-	# from top to bottom
-	$self->rebuild_all_coordinates();
-	return $self;
+    my $self = shift;
+    my ($child_widget) = validate_pos( @_, { isa => 'Curses::Toolkit::Widget' } );
+    scalar $self->get_children()
+        and die 'there is already a child widget';
+    $self->_add_child($child_widget);
+    $child_widget->_set_parent($self);
+
+    # because it's a Bin container, needs to take care of rebuilding coordinates
+    # from top to bottom
+    $self->rebuild_all_coordinates();
+    return $self;
 }
 
 
 
 sub remove_widget {
-	my ($self) = @_;
-	my @children = ();
+    my ($self) = @_;
+    my @children = ();
 
-	$self->{children} = Tie::Array::Iterable->new( @children );
-	return $self;
+    $self->{children} = Tie::Array::Iterable->new(@children);
+    return $self;
 }
 
 sub _rebuild_children_coordinates {
-	my ($self) = @_;
-	my $available_space = $self->_get_available_space();
-	my ($child_widget) = $self->get_children();
-	defined $child_widget or return;
+    my ($self)          = @_;
+    my $available_space = $self->_get_available_space();
+    my ($child_widget)  = $self->get_children();
+    defined $child_widget or return;
 
-	# Given the available space, how much does the child widget want ?
-	my $child_space = $child_widget->get_desired_space($available_space->clone());
-	# Make sure it's not bigger than what is available
-	$child_space->restrict_to($available_space);
-# 		# Force the child space to be as large as the available space
-# 		$child_space->set(x2 => $available_space->x2() );
-	# At the end, we grant it this space
-	$child_widget->_set_relatives_coordinates($child_space);
-	$child_widget->can('_rebuild_children_coordinates') and
-	  $child_widget->_rebuild_children_coordinates();
-	return $self;
+    # Given the available space, how much does the child widget want ?
+    my $child_space = $child_widget->get_desired_space( $available_space->clone() );
+
+    # Make sure it's not bigger than what is available
+    $child_space->restrict_to($available_space);
+
+    # 		# Force the child space to be as large as the available space
+    # 		$child_space->set(x2 => $available_space->x2() );
+    # At the end, we grant it this space
+    $child_widget->_set_relatives_coordinates($child_space);
+    $child_widget->can('_rebuild_children_coordinates')
+        and $child_widget->_rebuild_children_coordinates();
+    return $self;
 }
 
 1;
@@ -76,7 +80,7 @@ Curses::Toolkit::Widget::Bin - a bin widget
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
