@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::Button;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: a simple text button widget
@@ -23,122 +24,125 @@ use Curses::Toolkit::Object::Coordinates;
 
 
 sub new {
-	my $class = shift;
+    my $class = shift;
 
-	my $self = $class->SUPER::new();
-	$self->{text} = '';
-	return $self;
+    my $self = $class->SUPER::new();
+    $self->{text} = '';
+    return $self;
 }
 
 
 sub new_with_label {
-	my $class = shift;
-	my ($text) = validate_pos( @_, { type => SCALAR } );
+    my $class = shift;
+    my ($text) = validate_pos( @_, { type => SCALAR } );
 
-	my $self = $class->new();
-	$self->set_text($text);
-	return $self;
+    my $self = $class->new();
+    $self->set_text($text);
+    return $self;
 }
 
 
 sub set_text {
-	my $self = shift;
-	
-	my ($text) = validate_pos( @_, { type => SCALAR } );
-	$self->{text} = $text;
-	return $self;
+    my $self = shift;
+
+    my ($text) = validate_pos( @_, { type => SCALAR } );
+    $self->{text} = $text;
+    return $self;
 
 }
 
 
 sub get_text {
-	my ($self) = @_;
-	return $self->{text};
+    my ($self) = @_;
+    return $self->{text};
 }
 
 # <----- w1 ---->
 #   <-- w2 --->
 # < button text >
-# --^  o1 
-# ------- o2 --^ 
+# --^  o1
+# ------- o2 --^
 
 # <----- w1 ---->
 #   <-- w2 --->
 # < button text >
 # <> wl
 #              <> wr
-# --^  o1 
-# ------- o2 --^ 
+# --^  o1
+# ------- o2 --^
 
 
 
 sub draw {
-	my ($self) = @_;
-	$self->SUPER::draw(); # draw the border if any
+    my ($self) = @_;
+    $self->SUPER::draw(); # draw the border if any
 
-	my $theme = $self->get_theme();
-	my $c = $self->get_coordinates();
-	my $text = $self->get_text();
+    my $theme = $self->get_theme();
+    my $c     = $self->get_coordinates();
+    my $text  = $self->get_text();
 
-	my $left_string = $self->get_theme_property('left_enclosing');
-	my $right_string = $self->get_theme_property('right_enclosing');
-	my $bw = $self->get_theme_property('border_width');
-	my $wl = length $left_string;
-	my $wr = length $right_string;
+    my $left_string  = $self->get_theme_property('left_enclosing');
+    my $right_string = $self->get_theme_property('right_enclosing');
+    my $bw           = $self->get_theme_property('border_width');
+    my $wl           = length $left_string;
+    my $wr           = length $right_string;
 
-	my $w1 = $c->width() - 2 * $bw;
-	my $w2 = $w1 - $wl - $wr;
-	my $o1 = $wl;
-	my $o2 = $w1 - $wr;
-	my $t1 = ' ' x (($w2 - length $text) / 2);
-	my $t2 = ' ' x ($w2 - length($text) - length($t1) );
+    my $w1 = $c->width() - 2 * $bw;
+    my $w2 = $w1 - $wl - $wr;
+    my $o1 = $wl;
+    my $o2 = $w1 - $wr;
+    my $t1 = ' ' x ( ( $w2 - length $text ) / 2 );
+    my $t2 = ' ' x ( $w2 - length($text) - length($t1) );
 
-	$theme->draw_string($c->x1() + $bw, $c->y1() + $bw, $left_string);
-	$theme->draw_string($c->x1() + $bw + $o2, $c->y1() + $bw, $right_string);
-	$theme->draw_string($c->x1() + $bw + $o1, $c->y1() + $bw, $t1 . $text . $t2);
+    $theme->draw_string( $c->x1() + $bw,       $c->y1() + $bw, $left_string );
+    $theme->draw_string( $c->x1() + $bw + $o2, $c->y1() + $bw, $right_string );
+    $theme->draw_string( $c->x1() + $bw + $o1, $c->y1() + $bw, $t1 . $text . $t2 );
 
-	return;
+    return;
 }
 
 
-sub get_desired_space {	shift->get_minimum_space(@_) }
+sub get_desired_space { shift->get_minimum_space(@_) }
 
 
 sub get_minimum_space {
-	my ($self, $available_space) = @_;
-	my $text = $self->get_text();
+    my ( $self, $available_space ) = @_;
+    my $text = $self->get_text();
 
-	my $minimum_space = $available_space->clone();
-	my $bw = $self->get_theme_property('border_width');
-	my $left_string = $self->get_theme_property('left_enclosing');
-	my $right_string = $self->get_theme_property('right_enclosing');
-	$minimum_space->set( x2 => $available_space->x1() + 2 * $bw + length($left_string) + length($text) + length($right_string),
-						 y2 => $available_space->y1() + 1 + 2 * $bw,
-					   );
-	return $minimum_space;
+    my $minimum_space = $available_space->clone();
+    my $bw            = $self->get_theme_property('border_width');
+    my $left_string   = $self->get_theme_property('left_enclosing');
+    my $right_string  = $self->get_theme_property('right_enclosing');
+    $minimum_space->set(
+        x2 => $available_space->x1() + 2 * $bw + length($left_string) + length($text) + length($right_string),
+        y2 => $available_space->y1() + 1 + 2 * $bw,
+    );
+    return $minimum_space;
 }
 
 
 sub possible_signals {
-	my ($self) = @_;
-	return ( $self->SUPER::possible_signals(),
-			 clicked => 'Curses::Toolkit::Signal::Clicked',
-		   );
+    my ($self) = @_;
+    return (
+        $self->SUPER::possible_signals(),
+        clicked => 'Curses::Toolkit::Signal::Clicked',
+    );
 }
 
 
 sub _get_theme_properties_definition {
-	my ($self) = @_;
-	return { %{$self->SUPER::_get_theme_properties_definition() },
-			 left_enclosing => {
-			   optional => 0,
-			   type => SCALAR,
-			 },
-			 right_enclosing => {
-			   optional => 0,
-			   type => SCALAR,
-			 },
-		   }
+    my ($self) = @_;
+    return {
+        %{ $self->SUPER::_get_theme_properties_definition() },
+        left_enclosing => {
+            optional => 0,
+            type     => SCALAR,
+        },
+        right_enclosing => {
+            optional => 0,
+            type     => SCALAR,
+        },
+    };
 }
 
 1;
@@ -153,7 +157,7 @@ Curses::Toolkit::Widget::Button - a simple text button widget
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 Appearence
 
