@@ -10,7 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::Container;
-our $VERSION = '0.100320';
+our $VERSION = '0.100630';
+
 
 
 # ABSTRACT: a container widget
@@ -22,72 +23,73 @@ use Params::Validate qw(:all);
 
 
 sub new {
-	my $class = shift;
-	my $self = $class->SUPER::new(@_);
+    my $class = shift;
+    my $self  = $class->SUPER::new(@_);
 
-	use Tie::Array::Iterable;
-	my @children = ();
+    use Tie::Array::Iterable;
+    my @children = ();
 
-	$self->{children} = Tie::Array::Iterable->new( @children );
+    $self->{children} = Tie::Array::Iterable->new(@children);
 
-	return $self;
+    return $self;
 }
 
 
 sub render {
-	my ($self) = @_;
-	$self->blank();
-	foreach my $child ($self->get_children()) {
-		$child->render();
-	}
-	$self->draw();
+    my ($self) = @_;
+    $self->blank();
+    foreach my $child ( $self->get_children() ) {
+        $child->render();
+    }
+    $self->draw();
     return;
 }
 
 # default method for blanking
 sub blank {
-	my ($self) = @_;
-	my $theme = $self->get_theme();
-	my $c = $self->get_coordinates();
-	my $bc = $self->_get_available_space()
-	  + { x1 => $c->x1(), y1 => $c->y1(),
-		  x2 => $c->x1(), y2 => $c->y1(), };
-	$theme->draw_blank($bc);
-	return $self;
+    my ($self) = @_;
+    my $theme  = $self->get_theme();
+    my $c      = $self->get_coordinates();
+    my $bc     = $self->_get_available_space() + {
+        x1 => $c->x1(), y1 => $c->y1(),
+        x2 => $c->x1(), y2 => $c->y1(),
+    };
+    $theme->draw_blank($bc);
+    return $self;
 }
 
 
 sub get_children {
-	my ($self) = @_;
-	return @{$self->{children}};
+    my ($self) = @_;
+    return @{ $self->{children} };
 }
 
 sub _add_child {
-	my $self = shift;
-	return $self->_add_child_at_end(@_);
+    my $self = shift;
+    return $self->_add_child_at_end(@_);
 }
-	
+
 sub _add_child_at_end {
-	my ($self, $child_widget) = @_;
-	push @{$self->{children}}, $child_widget;
-	my $iterator = $self->{children}->forward_from(@{$self->{children}} - 1);
-	$child_widget->_set_iterator($iterator);
-	return $self;
+    my ( $self, $child_widget ) = @_;
+    push @{ $self->{children} }, $child_widget;
+    my $iterator = $self->{children}->forward_from( @{ $self->{children} } - 1 );
+    $child_widget->_set_iterator($iterator);
+    return $self;
 }
 
 sub _add_child_at_beginning {
-	my ($self, $child_widget) = @_;
-	unshift @{$self->{children}}, $child_widget;
-	my $iterator = $self->{children}->forward_from(0);
-	$child_widget->_set_iterator($iterator);	
-	return $self;
+    my ( $self, $child_widget ) = @_;
+    unshift @{ $self->{children} }, $child_widget;
+    my $iterator = $self->{children}->forward_from(0);
+    $child_widget->_set_iterator($iterator);
+    return $self;
 }
 
 # overload Widget's method : not sure why
 sub _set_relatives_coordinates {
-	my $self = shift;
-	$self->SUPER::_set_relatives_coordinates(@_);
-	return $self;
+    my $self = shift;
+    $self->SUPER::_set_relatives_coordinates(@_);
+    return $self;
 }
 
 # Returns the relative rectangle that a child widget can occupy.
@@ -97,13 +99,13 @@ sub _set_relatives_coordinates {
 # output : a Curses::Toolkit::Object::Coordinates object
 
 sub _get_available_space {
-	my ($self) = @_;
-	my $rc = $self->get_relatives_coordinates();
-	use Curses::Toolkit::Object::Coordinates;
-	return Curses::Toolkit::Object::Coordinates->new(
-		x1 => 0, y1 => 0,
+    my ($self) = @_;
+    my $rc = $self->get_relatives_coordinates();
+    use Curses::Toolkit::Object::Coordinates;
+    return Curses::Toolkit::Object::Coordinates->new(
+        x1 => 0,            y1 => 0,
         x2 => $rc->width(), y2 => $rc->height(),
-	);
+    );
 }
 
 1;
@@ -118,7 +120,7 @@ Curses::Toolkit::Widget::Container - a container widget
 
 =head1 VERSION
 
-version 0.100320
+version 0.100630
 
 =head1 DESCRIPTION
 
